## Introduction

This is an unofficial implementation of the paper: https://arxiv.org/abs/2011.08785
The aim of this project <is to provide a good entry point of retraining the algorithm on a different
dataset with different needs.

## Get Started

install all the requirements
````commandline
pip install -r requirements.txt
````

## How to use the GUI
this repository provides

## Roadmap

- [ ] Add Variable Image Sizes to the Padim Anomaly Detector
- [ ] Forward the variable image size to the GUI
- [ ] Add status message for training and calibration part
- [ ] rework home frame
- [ ] create api to serve the anomaly detection results
- [ ] add storing anomaly detectors (serializing to disk)